@@ -1,11 +1,10 @@
+use crate::task::api_credentials::ApiCredentials;
+use async_trait::async_trait;
 use reqwest;
 use reqwest::header::HeaderMap;
 use reqwest::Client;
 use serde_json::Value;
 use std::fmt;
-use crate::task::api_credentials::ApiCredentials;
-use serde_json::json;
-use async_trait::async_trait;
 
 #[async_trait]
 pub trait RestOperations {
@@ -30,8 +29,14 @@ impl RestClient {
         let api_credentials = self.get_api_credentials();
         let mut headers = HeaderMap::new();
 
-        headers.insert("x-api-user", api_credentials.get_user().to_owned().parse().unwrap());
-        headers.insert("x-api-key", api_credentials.get_key().to_owned().parse().unwrap());
+        headers.insert(
+            "x-api-user",
+            api_credentials.get_user().to_owned().parse().unwrap(),
+        );
+        headers.insert(
+            "x-api-key",
+            api_credentials.get_key().to_owned().parse().unwrap(),
+        );
 
         headers
     }
@@ -58,7 +63,7 @@ impl RestOperations for RestClient {
             .await
             .unwrap();
 
-        Ok(json!(response.text().await.unwrap()))
+        Ok(serde_json::from_str(&response.text().await.unwrap()).unwrap())
     }
 }
 
